==> mongodb-src-r4.0.3.tar.gz: mongodb-src-r4.0.3/src/mongo/embedded/service_entry_point_embedded.h <==
/**
 *    Copyright (C) 2018 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/disallow_copying.h"
#include "mongo/transport/service_entry_point.h"

namespace mongo {

/**
 * The entry point into mongod. Just a wrapper around assembleResponse.
 */
class ServiceEntryPointEmbedded final : public ServiceEntryPoint {
    MONGO_DISALLOW_COPYING(ServiceEntryPointEmbedded);

public:
    ServiceEntryPointEmbedded() = default;
    DbResponse handleRequest(OperationContext* opCtx, const Message& request) override;

    void startSession(transport::SessionHandle session) override;
    void endAllSessions(transport::Session::TagMask tags) override;
    bool shutdown(Milliseconds timeout) override;
    Stats sessionStats() const override;
    size_t numOpenSessions() const override;

private:
    class Hooks;
};

}  // namespace mongo

==> mongodb-src-r4.2.7.tar.gz: mongodb-src-r4.2.7/src/mongo/embedded/service_entry_point_embedded.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/transport/service_entry_point.h"

namespace mongo {

/**
 * The entry point into mongod. Just a wrapper around assembleResponse.
 */
class ServiceEntryPointEmbedded final : public ServiceEntryPoint {
    ServiceEntryPointEmbedded(const ServiceEntryPointEmbedded&) = delete;
    ServiceEntryPointEmbedded& operator=(const ServiceEntryPointEmbedded&) = delete;

public:
    ServiceEntryPointEmbedded() = default;
    DbResponse handleRequest(OperationContext* opCtx, const Message& request) override;

    void startSession(transport::SessionHandle session) override;
    void endAllSessions(transport::Session::TagMask tags) override;
    Status start() override;
    bool shutdown(Milliseconds timeout) override;
    void appendStats(BSONObjBuilder* bob) const override;
    size_t numOpenSessions() const override;

private:
    class Hooks;
};

}  // namespace mongo
